var NAVTREEINDEX19 =
{
"structpw__module__methods.html#ace8dfde4c073903664ba703b575f6e01":[6,4,9,3,1],
"structpw__node.html":[6,4,10,4],
"structpw__node__events.html":[6,4,10,2],
"structpw__node__events.html#a07c012e13056aed56de654a44590df89":[6,4,10,2,2],
"structpw__node__events.html#a37faf21db57a7e95999db521fb1cbcab":[6,4,10,2,0],
"structpw__node__events.html#a9a6cdaf300007bc554b0c0b6bdbf5ccd":[6,4,10,2,1],
"structpw__node__info.html":[6,4,10,1],
"structpw__node__info.html#a125f4d8851630b989c86fc0ebc83fba0":[6,4,10,1,6],
"structpw__node__info.html#a178dbb8570999efffa8584d13e52ce0e":[6,4,10,1,1],
"structpw__node__info.html#a48075df9117cf8e55b474c8d2d445a1d":[6,4,10,1,7],
"structpw__node__info.html#a737754b76140ca4751f2cd68667ffaa2":[6,4,10,1,0],
"structpw__node__info.html#a88bcfe3c9dbce8c5c6ac7b663e4db009":[6,4,10,1,3],
"structpw__node__info.html#aa2bd90f2d1c5f570eac18709b2acc387":[6,4,10,1,8],
"structpw__node__info.html#ab5c2457030a463ccdc6ca5291ced856f":[6,4,10,1,5],
"structpw__node__info.html#ac312e1844784e77e412f6bb341814372":[6,4,10,1,2],
"structpw__node__info.html#add4c3cdb14e0baa27c6c28d8c4a4d7f1":[6,4,10,1,9],
"structpw__node__info.html#ae3b1789c08bcae95888e042790c95b75":[6,4,10,1,4],
"structpw__node__methods.html":[6,4,10,3],
"structpw__node__methods.html#a01dbc165d13370efdb6a54a5c3f40f41":[6,4,10,3,1],
"structpw__node__methods.html#a0fee61facfa842f9be5b55815d78f49a":[6,4,10,3,4],
"structpw__node__methods.html#a1f28beb1b607ebd270f2e06b4f9a5266":[6,4,10,3,3],
"structpw__node__methods.html#a44bb3efe45f8a5c763cc62daaa099569":[6,4,10,3,0],
"structpw__node__methods.html#a66986c115ef6b4046c22774ea438a3ad":[6,4,10,3,2],
"structpw__node__methods.html#a9f04049f6b62d408dacdefe1aafcc802":[6,4,10,3,5],
"structpw__permission.html":[6,4,11,1],
"structpw__permission.html#a317a76bba04bd0dcad6e5bca65f9fa92":[6,4,11,1,0],
"structpw__permission.html#ac890cf00fa67d8667c9be52276e8a6f3":[6,4,11,1,1],
"structpw__port.html":[6,4,12,4],
"structpw__port__events.html":[6,4,12,2],
"structpw__port__events.html#a287b7ffb7f8f5b99b82bdd61d137cb1f":[6,4,12,2,1],
"structpw__port__events.html#ab9b6466b9ef1ed29b53c585e6d7d5885":[6,4,12,2,0],
"structpw__port__events.html#ac3ad235f94b8be2c65b694c8ebf26457":[6,4,12,2,2],
"structpw__port__info.html":[6,4,12,1],
"structpw__port__info.html#a3c95bbed7080e2f033b133409315f31a":[6,4,12,1,4],
"structpw__port__info.html#a5131d23e86aef3c0d1727a6aa6359e9c":[6,4,12,1,3],
"structpw__port__info.html#a59e2afe4f65b5f74eb7a28f51fb958aa":[6,4,12,1,2],
"structpw__port__info.html#ab8bd7cf30a25d379e02bfc66c5692c64":[6,4,12,1,0],
"structpw__port__info.html#ae58ded9d9277c0f93862d58026faf4e2":[6,4,12,1,1],
"structpw__port__methods.html":[6,4,12,3],
"structpw__port__methods.html#a3c19aedb668ea1a71bc12f89b106d94a":[6,4,12,3,2],
"structpw__port__methods.html#a77b4f3e654eb54c6066faa61fa478186":[6,4,12,3,0],
"structpw__port__methods.html#a902dc57cb5eaae752960a0667ff10ab8":[6,4,12,3,3],
"structpw__port__methods.html#adbe08858422d830443b9f111cd6d44bd":[6,4,12,3,1],
"structpw__profiler.html":[6,7,2,3],
"structpw__profiler__events.html":[6,7,2,1],
"structpw__profiler__events.html#a00e0a36b711bd01ce994d368e0e39629":[6,7,2,1,0],
"structpw__profiler__events.html#a1ca3197b5f29567d7dfa437d86695e9a":[6,7,2,1,1],
"structpw__profiler__methods.html":[6,7,2,2],
"structpw__profiler__methods.html#a036f959bbeba1ad5da22f20c0e66a1f8":[6,7,2,2,1],
"structpw__profiler__methods.html#a6d6488538db93934b63ad3ee7fc3cc9a":[6,7,2,2,0],
"structpw__properties.html":[6,6,6,1],
"structpw__properties.html#a70aa5816bde60f5511f2308971794881":[6,6,6,1,0],
"structpw__properties.html#a8003e978689f764bb7bd2a3ab2d46a87":[6,6,6,1,1],
"structpw__protocol.html":[6,5,13,6],
"structpw__protocol__client.html":[6,5,13,1],
"structpw__protocol__client.html#a020b1da93f4f58c485ff64da4a5ac655":[6,5,13,1,3],
"structpw__protocol__client.html#a03ad2913f7876e0db722b6d1e318e35f":[6,5,13,1,2],
"structpw__protocol__client.html#a0f94b0fb5b1f83cbb56529b5c43c4a8f":[6,5,13,1,4],
"structpw__protocol__client.html#a2f6233dcd7a026275a93680ae68ee263":[6,5,13,1,1],
"structpw__protocol__client.html#a4b60903a56e79e980b11ea2d14fac80c":[6,5,13,1,6],
"structpw__protocol__client.html#a4f79f140a57922a8c4b7d52f9f433918":[6,5,13,1,8],
"structpw__protocol__client.html#a9ce571a5bc950b3309d0dbd2a55e501f":[6,5,13,1,7],
"structpw__protocol__client.html#addd42578b59ddffc32a42a52754654be":[6,5,13,1,0],
"structpw__protocol__client.html#ae94059a4fa05da14961edb56be183f2a":[6,5,13,1,5],
"structpw__protocol__events.html":[6,5,13,5],
"structpw__protocol__events.html#ab341415c5d72294c801c580ac9653426":[6,5,13,5,1],
"structpw__protocol__events.html#af7bb9abb40f974acecda6bb2c6ad5cad":[6,5,13,5,0],
"structpw__protocol__implementation.html":[6,5,13,4],
"structpw__protocol__implementation.html#a237c5d6a817a2b5dddb0f2e996d0a0bd":[6,5,13,4,2],
"structpw__protocol__implementation.html#a859abf630e7a562357647c0bb7caccb6":[6,5,13,4,1],
"structpw__protocol__implementation.html#a8bf7e732f7cac47bba3b798c722f739a":[6,5,13,4,0],
"structpw__protocol__marshal.html":[6,5,13,3],
"structpw__protocol__marshal.html#a050ca46939a55d57319f7fe60630088e":[6,5,13,3,3],
"structpw__protocol__marshal.html#a1d2f780d6b77da347a46af7bf6577c4a":[6,5,13,3,6],
"structpw__protocol__marshal.html#a3b6e60e3abd02c572dc9717ea6128837":[6,5,13,3,2],
"structpw__protocol__marshal.html#a42d1730a083b2ddfef273c875f5a8da9":[6,5,13,3,0],
"structpw__protocol__marshal.html#a630f0a301e4fbf67698cf05b24179b30":[6,5,13,3,5],
"structpw__protocol__marshal.html#a84d23417562653ce0c3f833914745b4b":[6,5,13,3,1],
"structpw__protocol__marshal.html#a9082278f0db2ef7b0fab5ac315d5d4e6":[6,5,13,3,4],
"structpw__protocol__marshal.html#ab3d180b20e34b70959086148d1b6c9c5":[6,5,13,3,8],
"structpw__protocol__marshal.html#ade451b0a49d73a98a1c3cee60f6f9c8d":[6,5,13,3,7],
"structpw__protocol__native__demarshal.html":[6,7,3,2],
"structpw__protocol__native__demarshal.html#a3f981db467091f35ddb7e5ecb2bf0705":[6,7,3,2,2],
"structpw__protocol__native__demarshal.html#acc4296853e8e0def46f6269326b76198":[6,7,3,2,1],
"structpw__protocol__native__demarshal.html#ad4dcb55ad836d8f5cf303742aaae5ff2":[6,7,3,2,0],
"structpw__protocol__native__ext.html":[6,7,3,3],
"structpw__protocol__native__ext.html#a04968e51cb5e9777795800dce3eaaa76":[6,7,3,3,3],
"structpw__protocol__native__ext.html#a1a348ddd739378bbd4b996ef68de2adc":[6,7,3,3,8],
"structpw__protocol__native__ext.html#a356887f5340ad05b4b8ba90f26238565":[6,7,3,3,2],
"structpw__protocol__native__ext.html#a3de6ba89d6e099eee955acf2744a52da":[6,7,3,3,1],
"structpw__protocol__native__ext.html#a588964b2fd1a055deb2d0ab1455e3e9f":[6,7,3,3,0],
"structpw__protocol__native__ext.html#a6eb6702a7aaeaa50172d66ed9a6f818a":[6,7,3,3,4],
"structpw__protocol__native__ext.html#a92709bdf1f3f815be21a33f119b0d8e6":[6,7,3,3,6],
"structpw__protocol__native__ext.html#a9c23c3dab6c416b7f92e3b3684ddae88":[6,7,3,3,5],
"structpw__protocol__native__ext.html#aee24b5ce6da772ce4167bfd88a8c7cdb":[6,7,3,3,7],
"structpw__protocol__native__message.html":[6,7,3,1],
"structpw__protocol__native__message.html#a32d56d90a40415a584d28262cb30941e":[6,7,3,1,0],
"structpw__protocol__native__message.html#a45a77f421d3b6b1123b85883e28b48b3":[6,7,3,1,6],
"structpw__protocol__native__message.html#a60ea6289ac35a79b83b7e1caa0c8edf6":[6,7,3,1,2],
"structpw__protocol__native__message.html#a6c4a9b3a354cf7f37c8c4aa25de81d67":[6,7,3,1,4],
"structpw__protocol__native__message.html#abaad1bc5e0c163fa89fea9c0d0852c4f":[6,7,3,1,5],
"structpw__protocol__native__message.html#ad9a08cd2b12fa38a8d222308270faf40":[6,7,3,1,3],
"structpw__protocol__native__message.html#aef6ddaa16aeaa35b4276e3b2767268aa":[6,7,3,1,1],
"structpw__protocol__server.html":[6,5,13,2],
"structpw__protocol__server.html#a01d6fae5e363f6694f092256c19366ea":[6,5,13,2,3],
"structpw__protocol__server.html#a0ac79f449a098fd48ac49f48f56a0ed3":[6,5,13,2,0],
"structpw__protocol__server.html#a0b93bd3cd5a2680d8ece4796826406fc":[6,5,13,2,1],
"structpw__protocol__server.html#acc7b1e9530a048b084976fc647ab446f":[6,5,13,2,4],
"structpw__protocol__server.html#ae953d4026c613d91a0cb34398d3f4367":[6,5,13,2,2],
"structpw__proxy.html":[6,4,13,2],
"structpw__proxy__events.html":[6,4,13,1],
"structpw__proxy__events.html#a1d91d77027018205abcdfe5f25b0feb1":[6,4,13,1,4],
"structpw__proxy__events.html#a25e8553fd0ed2f729ffe61994f6973a2":[6,4,13,1,0],
"structpw__proxy__events.html#a8072b9d1ea7e1c91cce89de75d1c7e61":[6,4,13,1,3],
"structpw__proxy__events.html#a8916a9be2fa3763221fdf64f79468d14":[6,4,13,1,2],
"structpw__proxy__events.html#aaa8802aa5a62fdc422f8db0d606adac3":[6,4,13,1,1],
"structpw__proxy__events.html#af8e0510a58d92ddd0831293e1c42b867":[6,4,13,1,5],
"structpw__registry.html":[6,4,4,5],
"structpw__registry__events.html":[6,4,14,1],
"structpw__registry__events.html#a3fa28cf2cd3ed8739debec5bb17ace61":[6,4,14,1,2],
"structpw__registry__events.html#a94464d7de86207e80a3dff93974b1a01":[6,4,14,1,0],
"structpw__registry__events.html#a9a62b37a711f65f1014cb27b92ae2689":[6,4,14,1,1],
"structpw__registry__methods.html":[6,4,14,2],
"structpw__registry__methods.html#a743174c4df93282f1361f137383cb41a":[6,4,14,2,2],
"structpw__registry__methods.html#a82488a74c02c5b764b0764b0d3e42fac":[6,4,14,2,0],
"structpw__registry__methods.html#a91a13e6dbf685af929ced294d5816089":[6,4,14,2,1],
"structpw__registry__methods.html#afe6865901f9bc87f009674959d12e60c":[6,4,14,2,3],
"structpw__resource.html":[6,5,14,2],
"structpw__resource__events.html":[6,5,14,1],
"structpw__resource__events.html#a0472df3f84251f7c7f5a36692bd0ac6e":[6,5,14,1,1],
"structpw__resource__events.html#a0a276ed65fe8f88887e9fbd0d08df018":[6,5,14,1,2],
"structpw__resource__events.html#a41e29d4a60ff80ff183c2cb56060f7e9":[6,5,14,1,0],
"structpw__resource__events.html#af8ab8db63d0b4e3a332ff552e416e5a2":[6,5,14,1,3],
"structpw__session.html":[6,7,4,24],
"structpw__session__events.html":[6,7,4,10],
"structpw__session__events.html#a0b39596a01a8c3d325dcf0548c64dc29":[6,7,4,10,2],
"structpw__session__events.html#a7199c3db69d83133dfdf110524ea90b4":[6,7,4,10,1],
"structpw__session__events.html#a9156a82a54dba4f5e6f7b045a31b5ac7":[6,7,4,10,0],
"structpw__session__info.html":[6,7,4,18],
"structpw__session__info.html#a00aaf0720fd58ae285a1fe122ab0fb93":[6,7,4,18,3],
"structpw__session__info.html#a1289ec21ec9441f29314a561b341cf13":[6,7,4,18,2],
"structpw__session__info.html#aa2d06aa8a36c3da1890e37f02e4702a6":[6,7,4,18,1],
"structpw__session__info.html#aa58e4f042f5cf3226d0765654439a9a3":[6,7,4,18,0],
"structpw__session__info.html#abfebf0a6ad9331c4690ffad37894d660":[6,7,4,18,4],
"structpw__session__methods.html":[6,7,4,11],
"structpw__session__methods.html#a39a82c063c97d967e5ee82589c390c29":[6,7,4,11,0],
"structpw__session__methods.html#a66e604601841f9f2252db7c4a4466f6f":[6,7,4,11,4],
"structpw__session__methods.html#a6720d4c6b23022393bc945c656ba5fe0":[6,7,4,11,2],
"structpw__session__methods.html#a9311ff4c5e45bce0b1a56ee64e720b09":[6,7,4,11,3],
"structpw__session__methods.html#afeb231bfac6c5539d258eb06b22e0acf":[6,7,4,11,1],
"structpw__stream.html":[6,0,5],
"structpw__stream__control.html":[6,0,2],
"structpw__stream__control.html#a40b47654929367a6a4f1b83b0b68bfb1":[6,0,2,3],
"structpw__stream__control.html#a4167f3df47a2d2deff793d3f1f6d31d2":[6,0,2,0],
"structpw__stream__control.html#a4541b454ba4caaf23f4e772f431294c1":[6,0,2,1],
"structpw__stream__control.html#a4ffcfbdb7762b0650a28f10eb8c10046":[6,0,2,6],
"structpw__stream__control.html#a61f6208ade53511ac42e01185f270f62":[6,0,2,2],
"structpw__stream__control.html#a925311b76a91a9034391da7343865091":[6,0,2,5],
"structpw__stream__control.html#addabfd3b77bb0cb58bb65b779ab1b3d5":[6,0,2,4],
"structpw__stream__events.html":[6,0,4],
"structpw__stream__events.html#a0cdc45fef5f2458a0fd11a6e9ef1f6fb":[6,0,4,7],
"structpw__stream__events.html#a12fa5918ff2c41cc41d5bf8ae36b3ca3":[6,0,4,3],
"structpw__stream__events.html#a1de8432b45484bc0e060162b78720c02":[6,0,4,11],
"structpw__stream__events.html#a4d1ed03aa78fb2c8324ae13bc45731e3":[6,0,4,5],
"structpw__stream__events.html#a512bd219ce44ba1a688d600773efe84b":[6,0,4,8],
"structpw__stream__events.html#a66e43e35eb2be261520cda8a4e24098c":[6,0,4,10],
"structpw__stream__events.html#a74aaca4c31e44dad69aba50607055419":[6,0,4,0],
"structpw__stream__events.html#a89192aed5fcd89314bf7cc7ef6b21085":[6,0,4,2],
"structpw__stream__events.html#aab4b9831ef563920b401b1f9daf93042":[6,0,4,9],
"structpw__stream__events.html#abbe98bb0d78e6411d08244495f349b0b":[6,0,4,1],
"structpw__stream__events.html#abd09d7c76b0e14a201a438f09e609b29":[6,0,4,6],
"structpw__stream__events.html#ad60b819ff0ea17b0bd8833220cbd4a3e":[6,0,4,4],
"structpw__thread__loop.html":[6,5,15,2],
"structpw__thread__loop__events.html":[6,5,15,1],
"structpw__thread__loop__events.html#a3c806806a4d07a0b3735f4b625740652":[6,5,15,1,1],
"structpw__thread__loop__events.html#a6815fa728af5ab602c111e7c5b680387":[6,5,15,1,0],
"structpw__time.html":[6,0,3],
"structpw__time.html#a1ea3fa77ce4221df0d5ac3ad8fd1f6c7":[6,0,3,3],
"structpw__time.html#a41d793c390eefc6aee165e16e0d7c898":[6,0,3,1],
"structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff":[6,0,3,5],
"structpw__time.html#a91dafbb38397328f8705e2bb20b7625a":[6,0,3,4],
"structpw__time.html#a92d7a1849d4dc044d2fa64bd35a7a57d":[6,0,3,6],
"structpw__time.html#a99e3d7963e24fbf410afa03c73465328":[6,0,3,2],
"structpw__time.html#ad817da21bea1591d70f837c251a73468":[6,0,3,0],
"structpw__time.html#aebd42745267531bc23e1ee34dd759607":[6,0,3,7],
"structpw__work__queue.html":[6,5,16,1],
"structpwtest__context.html":[6,2,2],
"structpwtest__spa__plugin.html":[6,2,1],
"structpwtest__spa__plugin.html#a22553184b5d864e926e17d976cffca9f":[6,2,1,2],
"structpwtest__spa__plugin.html#a8bb79b9b0e5cb045fa2686edde9c3d34":[6,2,1,5],
"structpwtest__spa__plugin.html#ad517984d1206a29ad28eb83f19f41dbe":[6,2,1,0],
"structpwtest__spa__plugin.html#adc8a853d256b3dca56a3e805dc96c5b4":[6,2,1,3],
"structpwtest__spa__plugin.html#ae819473de8479871a6cd78f10a97ce68":[6,2,1,1],
"structpwtest__spa__plugin.html#aef8a87ec887314f7a70366be56138406":[6,2,1,4],
"structpwtest__suite.html":[6,2,3],
"structpwtest__test.html":[6,2,4],
"structspa__audio__aec.html":[7,0,137],
"structspa__audio__aec.html#a09e1e6ddb6cba06861e418fad8eb2442":[7,0,137,1],
"structspa__audio__aec.html#a2c343b0ced8bc8a9d22c441558c1cc9f":[7,0,137,2],
"structspa__audio__aec.html#a472c09f9a147170d0892a650b60c9b5d":[7,0,137,0],
"structspa__audio__aec__events.html":[7,0,138],
"structspa__audio__aec__events.html#a355f3bedb9b4094912577187225797d9":[7,0,138,1],
"structspa__audio__aec__events.html#ab137f922d3a547caf388c5c11be2e5ce":[7,0,138,0],
"structspa__audio__aec__info.html":[7,0,139],
"structspa__audio__aec__info.html#a88dbf8b905a3f808af985764cb21fd7c":[7,0,139,0],
"structspa__audio__aec__methods.html":[7,0,140],
"structspa__audio__aec__methods.html#a07bacc70c12928c5aa162d88c9146719":[7,0,140,4],
"structspa__audio__aec__methods.html#a0e357608392e4e4cf8224a523882a80c":[7,0,140,1],
"structspa__audio__aec__methods.html#a7d3939359e6ad34abf58f74cd0545118":[7,0,140,3],
"structspa__audio__aec__methods.html#aa16a3e41c4991532b50dc33f3f6001d7":[7,0,140,2],
"structspa__audio__aec__methods.html#af6f30eee3a6af553b3e6ef83f850a691":[7,0,140,0],
"structspa__audio__info.html":[6,8,7,20],
"structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b":[6,8,7,20,5],
"structspa__audio__info.html#a0c0ba9b2cb3625fdbfa3a5f1a00639d3":[6,8,7,20,6],
"structspa__audio__info.html#a1831d447b0446ff947e879f2de34d410":[6,8,7,20,3],
"structspa__audio__info.html#a5470ad19233fb9e3136d500296a74d75":[6,8,7,20,1],
"structspa__audio__info.html#a755a925f66d28b0e9912482e97375b7a":[6,8,7,20,2],
"structspa__audio__info.html#a99282e01caf417fe4ee63458ccdb6b30":[6,8,7,20,0],
"structspa__audio__info.html#aa02a98d24c25c529d6b387ed1eb7074e":[6,8,7,20,4],
"structspa__audio__info__dsd.html":[6,8,7,19],
"structspa__audio__info__dsd.html#a4f11fce0402edcbe61f0b35f27396ac9":[6,8,7,19,5],
"structspa__audio__info__dsd.html#a563add98a612fe3617a58e2cb1a703bc":[6,8,7,19,4],
"structspa__audio__info__dsd.html#a698a141255b6d57f04d56de0fa52d170":[6,8,7,19,0],
"structspa__audio__info__dsd.html#a72a8060d8747abb6e380e0dc0261157e":[6,8,7,19,3],
"structspa__audio__info__dsd.html#a902dd094aab140dc3500a3a36ef967da":[6,8,7,19,2],
"structspa__audio__info__dsd.html#a9f7ed724310d9b5a2c95607399fe3a34":[6,8,7,19,1],
"structspa__audio__info__dsp.html":[6,8,7,24],
"structspa__audio__info__dsp.html#ab59df8be3387df377c8b698346aa234f":[6,8,7,24,0],
"structspa__audio__info__iec958.html":[6,8,7,21],
"structspa__audio__info__iec958.html#ab4797480f2e4e7f25d19a0a42c748eac":[6,8,7,21,1],
"structspa__audio__info__iec958.html#adc76e7bde0fc3d66ffa5a8442c3b1409":[6,8,7,21,0],
"structspa__audio__info__iec958.html#af028b6675757cd4504ad1b11a2e746c7":[6,8,7,21,2],
"structspa__audio__info__raw.html":[6,8,7,23],
"structspa__audio__info__raw.html#a542692f9d3518632e37ea575d13ca149":[6,8,7,23,0],
"structspa__audio__info__raw.html#a5a7e0c093143ba0820e936ece11f0952":[6,8,7,23,3],
"structspa__audio__info__raw.html#a696f18b889bb8a5496e16dd48f7d8e01":[6,8,7,23,1],
"structspa__audio__info__raw.html#ac21ae45356ef4e1dbfde141937fde9c5":[6,8,7,23,4],
"structspa__audio__info__raw.html#ae7e501bbfbef2cd75f3ae0f13719652c":[6,8,7,23,2],
"structspa__audio__layout__info.html":[6,8,7,22],
"structspa__audio__layout__info.html#a939d325d78f6c2cb4492fda99fe3efd0":[6,8,7,22,1],
"structspa__audio__layout__info.html#abd815a9154f329d6a02f84f222bca93a":[6,8,7,22,0],
"structspa__buffer.html":[6,8,1,7],
"structspa__buffer.html#a026a97e0dfd3a606480f436fa61e204b":[6,8,1,7,0],
"structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e":[6,8,1,7,2],
"structspa__buffer.html#ad4c72bfda8875b33b7316af4bafb9560":[6,8,1,7,3],
"structspa__buffer.html#adbf5510ef0707e22b19980c84b61a073":[6,8,1,7,1],
"structspa__buffer__alloc__info.html":[6,8,1,4],
"structspa__buffer__alloc__info.html#a2598f62c920f42fd1ea6547968c0e2a6":[6,8,1,4,11],
"structspa__buffer__alloc__info.html#a30233569ad362f458d9e1344d0b5a58c":[6,8,1,4,10],
"structspa__buffer__alloc__info.html#a49810ff55f219eea5c1e4a3e2f24cd4c":[6,8,1,4,2]
};
